<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xsi:schemaLocation="http://www.w3.org/1999/XSL/Format fop.xsd ">

	<xsl:output method="xml" encoding="utf-8" indent="yes"/>

	<xsl:template match="/">
		<fo:root>

			<fo:layout-master-set>
				<fo:simple-page-master master-name="two-bodies"
					page-width="210mm" page-height="297mm" margin="10mm">
					<fo:region-body margin="27mm 0 100mm 0" region-name="top"/>
					<fo:region-body margin="177mm 0 0 0" region-name="down"/>
					<fo:region-before extent="27mm" />
				</fo:simple-page-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="two-bodies">
				<fo:static-content flow-name="xsl-region-before">
					<fo:block>Header</fo:block>
				</fo:static-content>
				<fo:flow flow-name="top">
					<xsl:apply-templates select="main-content"/>
				</fo:flow>
				<fo:flow flow-name="down">
					<xsl:apply-templates select="bottom-content"/>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template match="company">
		<fo:block font-family="Verdana, sans-serif"
				font-size="12pt">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<xsl:template match="company/name">
		<fo:block font-size="18pt" font-weight="bold"
				text-align="center" margin="12pt 0">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<xsl:template match="department">
		<fo:block space-before.minimum="12pt" space-after.minimum="6pt">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>


	<xsl:template match="department/name">
		<fo:block font-size="16pt" font-weight="bold" font-style="italic"
				text-align="left" margin-bottom="6pt">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>


	<xsl:template match="person">
		<fo:block space-before.minimum="12pt" padding="0.5em"
				border-width="1.5pt" border-style="solid" border-color="#664400"
				background-color="#FFFFCC">
			<fo:block font-size="14pt">
				<xsl:apply-templates select="fname" />
				<xsl:text> </xsl:text>
				<xsl:apply-templates select="surname" />
			</fo:block>
			<fo:block margin-top="0.5em">
				<xsl:apply-templates select="phone" />
			</fo:block>
			<fo:block margin-top="0.5em">
				<xsl:apply-templates select="email" />
			</fo:block>
		</fo:block>
	</xsl:template>

	<xsl:template match="person[@position='manager']/surname">
		<fo:inline font-weight="bold">
			<xsl:apply-templates />
		</fo:inline>
	</xsl:template>

	<xsl:template match="phone">
		<fo:block>
			<xsl:choose>
				<xsl:when test="@type='mobile'">mob.&#xA0;</xsl:when>
				<xsl:otherwise>tel.&#xA0;</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>

	<xsl:template match="email">
		<fo:block font-style="italic">
			<xsl:apply-templates />
		</fo:block>
	</xsl:template>
</xsl:stylesheet>
